@@ -1,5 +1,5 @@
-import random
 import datetime
+import random
 import re
 
 
@@ -23,14 +23,22 @@ def format_datetime(dt):
         ret = ''
         pattern = re.compile('\\d{2}-\\d{2}')
         pattern2 = re.compile('\\d{4}-\\d{2}-\\d{2}')
+        pattern3 = re.compile('\\d{2}:\\d{2}')
+        pattern4 = re.compile('\\d{2}月\\d{2}日 \\d{2}:\\d{2}')
         if '分钟前' in dt:
-            m = int(dt.split('分钟')[0].strip())
+            # m = int(dt.split('分钟')[0].strip())
+            mpattern = re.compile('(\\d+)分钟前')
+            m = int(re.findall(mpattern, dt)[0])
             ret = (datetime.datetime.now() - datetime.timedelta(minutes=m)).strftime("%Y-%m-%d %H:%M:%S")
         elif '小时前' in dt:
-            ms = int(dt.split('小时')[0].strip()) * 60
+            # ms = int(dt.split('小时')[0].strip()) * 60
+            hpattern = re.compile('(\\d+)小时前')
+            ms = int(re.findall(hpattern, dt)[0]) * 60
             ret = (datetime.datetime.now() - datetime.timedelta(minutes=ms)).strftime("%Y-%m-%d %H:%M:%S")
         elif '秒前' in dt:
-            secs = int(dt.split('秒')[0].strip())
+            # secs = int(dt.split('秒')[0].strip())
+            secspattern = re.compile('(\\d+)秒前')
+            secs = int(re.findall(secspattern, dt)[0])
             ret = (datetime.datetime.now() - datetime.timedelta(seconds=secs)).strftime("%Y-%m-%d %H:%M:%S")
         elif '天前' in dt:
             d = int(dt.split('天')[0].strip())
@@ -49,12 +57,27 @@ def format_datetime(dt):
         elif re.match(pattern2, dt):
             dtformat = datetime.datetime.strptime(dt, '%Y-%m-%d')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
+        elif re.match(pattern3, dt):
+            dtformat = datetime.datetime.strftime(datetime.datetime.now(), '%Y-%m-%d') + ' '
+            ret = dtformat + dt
+        elif re.match(pattern4, dt):
+            strdate = str(datetime.datetime.now().year) + '-' + dt
+            strdate = strdate.replace('月', '-')
+            ret = strdate.replace('日', '')
         elif '+0800' in dt:
             dtformat = datetime.datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
+        elif '发布时间：' in dt:
+            ret = dt.split('发布时间：')[-1].strip()
         else:
             ret = dt
     except Exception as e:
         print(e.args)
     finally:
         return ret
+
+
+def format_string(text):
+    pattern = re.compile('<[A-Za-z\\/].*?>')
+    text = re.sub(pattern, '', text)
+    return text
